import requests
import re

""" Класс инициализирует новые принтеры, собирая базовую инфу
    Производитель : prod, Локацию: locate - сеть в котором находится принтер: locate
    InitPrinter(ip).init_info возвращает базовую инфу для инициализации нового принтера
    ('192.168.1.36', 'KYOCERA', 'Olimp')
"""


class InitPrinter:
    def __init__(self, ip_address):
        self.ip_address = ip_address
        self.main_page = self.__get_main_page_printer()
        self.locate = self.find_locate(ip_address)
        self.prod = self.get_prod_printer()

    @staticmethod
    def find_locate(ip_address):
        f = re.findall(r"\d*.\d*.(\d*)\d.\d*", ip_address)[0]
        if f == '1':
            locate = 'Olimp'
        elif f == '2':
            locate = 'Sunmarinn'
        elif f == '4':
            locate = 'Aurum'
        else:
            locate = 'Неизвестно'
        return locate

    def __get_main_page_printer(self):
        r = None
        detect_refresh = r'(http-equiv="refresh")'   # regular ex for find refresh redirect
        redirect_url = r'url=(.*)"'                  # read new url
        url = f'http://{self.ip_address}/'
        cookies = {'Cookie': 'SESSION_ID=1'}
        try:
            r = requests.get(url, cookies=cookies).text
            if re.findall(detect_refresh, r):
                re_url = re.findall(redirect_url, r)[0]
                new_url = url+re_url
                r = requests.get(new_url).text      # getting redirect page
                return r
        except requests.exceptions.ConnectionError:
            r = 'ConnectTimeout'
        finally:
            return r

    def get_prod_printer(self):
        prod = 'Неопределен'
        factory = ['KYOCERA', 'HP', 'PANTUM', 'XEROX']
        for x in factory:

            if x in self.main_page.upper():
                prod = x
            else:
                pass
        return prod

    def init_info(self):
        return self.ip_address, self.prod, self.locate


if __name__ == "__main__":
    ip = '10.12.11.87'
    printer = InitPrinter(ip)
    print(printer.init_info())



from sub_main import InitPrinter
from manufacturers.KYOCERA.major_kyocera import KyoceraMajor
from manufacturers.HP.major_hp import HPMajor
from manufacturers.PANTUM.major_pantum import PantumMajor
from manufacturers.Xerox.major_xerox import XeroxMajor


class PeoplePrinter(InitPrinter):
    def __init__(self, ip_address):
        super().__init__(ip_address)

    def info(self):
        if self.prod == 'KYOCERA':
            x = KyoceraMajor
        elif self.prod == 'HP':
            x = HPMajor
        elif self.prod == 'PANTUM':
            x = PantumMajor
        elif self.prod == 'XEROX':
            x = XeroxMajor
        else:
            return 'Производитель неизвестен'
        return self.work(x(self.ip_address))

    # Принимает определенный класс производителя принтера
    def work(self, printer):
        return {
                'ip_address': self.ip_address,
                'mac_address': printer.mac(),
                'host_name': printer.host_name(),
                'prod': self.prod,
                'model': printer.model(),
                'locate': self.locate,
                'toner_lvl': printer.toner(),
                'prints_count': printer.prints_count()
                }


if __name__ == "__main__":
    ip = '10.12.21.87'
    printer = PeoplePrinter(ip)
    print(printer.info())


    # Возвращает словарь со всей инфой
    # {'ip_address': '192.168.1.39', 'mac_address': '00:17:C8:A0:4D:89', 'host_name': 'NetPRN1-AMBRA', 'prod': 'KYOCERA', 'model': 'ECOSYS M2735dn', 'locate': 'Olimp', 'toner_lvl': 75, 'prints_count': 24109}
    # получаем данные по ключу printer.full_info()['mac_address']


import time
import requests
import re


# def get_3040(ip_address):
#     url = f'http://{ip_address}/dvcinfo/dvcconfig/DvcConfig_Config.htm'
#
#     headers = {'Cookie': 'rtl=0; css=0',
#                'Referer': f"http://{ip_address}/startwlm/Start_Wlm.htm"}
#
#
#
#     page_code_info = requests.get(url, headers=headers)
#     print(page_code_info.text)
#     mac = re.findall(r'ComnAddLabelProperty\(\'2\'\,mes\[175\]\+" :",(".{17}")', page_code_info.text)[0]
#     model = re.findall(r'ComnAddLabelProperty\(\'2\'\,mes\[0\].*"(.*)","w272px"', page_code_info.text)[0]                # получть Модель
#     host_name = re.findall(r'ComnAddLabelProperty\(\'2\'\,mes\[1\].*"(.*)","w272px"', page_code_info.text)[0]         # получить HostName



class Kyocera3040:
    def __init__(self, ip_address):
        self.ip_address = ip_address
        self.headers = {'Cookie': 'rtl=0; css=0', 'Referer': f"http://{self.ip_address}/esu/DeepSleepApply.htm"}
        self._main_page = self._get_main_page()
        self._page_info = self._get_info_page()
        self._page_toner = self._get_toner_page()
        self._page_counter = self._page_counter()

    def _get_main_page(self):
        main_page = requests.get(f'http://{self.ip_address}/').text
        if 'DeepSleep.htm' in main_page:
            self._awakening()
        else:
            return main_page

    def _awakening(self):
        url = f'http://{self.ip_address}/esu/set.cgi'
        data = 'submit001=%D0%9F%D1%83%D1%81%D0%BA&okhtmfile=DeepSleepApply.htm&func=wakeup'
        requests.post(url, headers=self.headers, data=data)
        time.sleep(5)
        self._get_main_page()

    def _get_info_page(self):
        url_config = f'http://{self.ip_address}/dvcinfo/dvcconfig/DvcConfig_Config.htm'
        page_code_info = requests.get(url_config, headers=self.headers)
        return page_code_info.text

    def _get_toner_page(self):
        url_toner = f'http://{self.ip_address}/dvcinfo/dvccounter/DvcInfo_Counter_PrnCounter.htm'
        page_code_toner = requests.get(url_toner, headers=self.headers)
        return page_code_toner.text

    def _page_counter(self):
        url_counter = f'http://{self.ip_address}/dvcinfo/dvccounter/DvcInfo_Counter_PrnCounter.htm'
        page_code_counter = requests.get(url_counter, headers=self.headers)
        return page_code_counter.text

    def mac(self):
        mac = re.findall(r'ComnAddLabelProperty\(\'2\'\,mes\[175\]\+" :",(".{17}")', self._page_info)[0]
        return mac

    def host_name(self):
        host_name = re.findall(r'ComnAddLabelProperty\(\'2\'\,mes\[1\].*"(.*)","w272px"', self._page_info)[0]
        return host_name

    def model(self):
        model = re.findall(r'ComnAddLabelProperty\(\'2\'\,mes\[0\].*"(.*)","w272px"', self._page_info)[0]
        return model

    def toner(self):
        toner_lvl = 'Error'
        try:
            data_toner = re.findall(r".*parseInt\('(\d*)',10\)\)", self._page_toner)  # получить остаток тонера
            toner_lvl = int(data_toner[0])
        except (ValueError, IndexError):
            pass
        finally:
            return toner_lvl

    def prints_count(self):
        printed_total = re.findall(r"counterBlackWhite.0....(\d*)", self._page_counter)[0]  # получить оттиски
        copy_total = re.findall(r"counterBlackWhite.1....(\d*)", self._page_counter)[0]  # получить сканы
        prints_count = int(printed_total) + int(copy_total)  # получить cумму
        return prints_count


if __name__ == "__main__":
    ip = '192.168.1.33'
    print(Kyocera3040(ip))


import re
import requests
from bs4 import BeautifulSoup


class HPMajor:
    def __init__(self, ip_address):
        self.ip_address = ip_address
        self._page_with_info = self._get_info_page()
        self._page_toner = self._get_toner_page()

    def _get_info_page(self):
        url_info = f'''http://{self.ip_address}/info_configuration.html?tab=Home&menu=DevConfig'''
        page_code_info = requests.get(url_info).text
        bs_code_info = BeautifulSoup(page_code_info, "html.parser")
        return bs_code_info

    def _get_toner_page(self):
        url_toner = f'''http://{self.ip_address}/info_suppliesStatus.html?tab=Home&menu=SupplyStatus'''  # page with toner
        page_code_toner = requests.get(url_toner).text
        bs_code_toner = BeautifulSoup(page_code_toner, "html.parser")
        return bs_code_toner

    def mac(self):
        td = self._page_with_info.find("td", string='Аппаратный адрес:')
        td_parent = td.find_parent('tr')
        mac_address_unsorted = td_parent.find(class_='itemFont').text
        mac_address = (re.findall(r"(\w\w.*\w\w)", mac_address_unsorted)[0]).upper()
        return mac_address

    def host_name(self):
        td = self._page_with_info.find("td", string='Имя хоста:')
        td_parent = td.find_parent('tr')
        host_name_unsorted = td_parent.find(class_='itemFont').text
        host_name = (re.findall(r"(\w\w.*\w\w)", host_name_unsorted)[0]).upper()
        return host_name

    def model(self):
        td = self._page_with_info.find("td", string='Название продукта:')
        td_parent = td.find_parent('tr')
        model = td_parent.find(class_='itemFont').text
        return model

    def toner(self):
        data_toner = self._page_toner.find(class_='SupplyName width35 alignRight')
        toner_lvl = (re.findall(r"(\d+)", data_toner.text)[0])
        return toner_lvl

    def prints_count(self):
        td = self._page_with_info.find("td", string='Всего оттисков:')
        td_parent = td.find_parent('tr')
        prints_count = td_parent.find(class_='itemFont').text
        return prints_count

    # def full_info(self):
    #     return {'ip_address': self.ip_address, 'mac_address': self.mac, 'host_name': self.host_name, 'prod': self.prod,
    #             'model': self.model, 'locate': self.locate, 'toner_lvl': self.toner, 'prints_count': self.prints_count,
    #             'status': 'Done'}


if __name__ == "__main__":
    ip = '192.168.2.104'
    print(HPMajor(ip).mac)



import requests
import re
#
# # def get():
# #     s = requests.Session()
# #     # url = 'http://192.168.2.42/status/consumables.dhtml'
# #
# #     url = 'http://192.168.2.42/properties/generalSetup/billingCounters/billing_info.dhtml'
# #     cookies = {'Cookie': 'SESSION_ID=1'}
# #     total_r = r"Total Impressions:\n.*\n.*\n...(\d*)"
# #     total = re.findall(r"Total Impressions:\n.*\n.*\n...(\d*)", total_r)[0]
# #     print(total)
# #     print(s.get(url, cookies=cookies).text)
#
# def get_counts(ip_address):
#     url = f'http://{ip_address}/properties/generalSetup/billingCounters/billing_info.dhtml'
#     cookies = {'Cookie': 'SESSION_ID=1'}
#     r = requests.get(url, cookies=cookies).text
#     total_counts = re.findall(r"Total Impressions:\n.*\n.*\n...(\d*)", r)[0]
#     return total_counts
#
#
# def get_toner(ip_address):
#     url = f'http://{ip_address}/status/consumables.dhtml'
#     cookies = {'Cookie': 'SESSION_ID=1'}
#     r = requests.get(url, cookies=cookies).text
#
# def get():
#     url = 'http://192.168.2.145/properties/generalSetup/configuration/configuration.dhtml'
#     cookies = {'Cookie': 'SESSION_ID=1'}
#     r = requests.get(url, cookies=cookies)
#     print(r.text)


class XeroxMajor:
    def __init__(self, ip_address):
        self.ip_address = ip_address
        self.headers = {'Cookie': 'SESSION_ID=1'}
        self._page_info = self._get_config_page()
        self._page_toner = self._get_toner_page()
        self._page_counter = self._page_counter()

    def _get_config_page(self):
        url_info = f'http://{self.ip_address}/properties/generalSetup/configuration/configuration.dhtml'
        page_code_info = requests.get(url_info, headers=self.headers)
        return page_code_info.text

    def _get_toner_page(self):
        url_toner = f'http://{self.ip_address}/status/consumables.dhtml'
        page_code_toner = requests.get(url_toner, headers=self.headers)
        return page_code_toner.text

    def _page_counter(self):
        url_counter = f'http://{self.ip_address}/properties/generalSetup/billingCounters/billing_info.dhtml'
        page_code_counter = requests.get(url_counter, headers=self.headers)
        return page_code_counter.text

    def mac(self):
        mac_address = re.findall(r"MAC Address:[\r\n].*[\r\n].*[\r\n].*[\r\n]....(.*).{3}", self._page_info)[0]
        return mac_address

    def host_name(self):
        host_name = re.findall(r"Device Name:[\r\n].*[\r\n].*[\r\n].*[\r\n]....(.*).{2}", self._page_info)[0]
        return host_name

    def model(self):
        model = 'MODEL'
        return model

    def toner(self):
        total_toner = re.findall(r'tonerLife...."(.*)"', self._page_toner)[0]
        return total_toner

    def prints_count(self):
        total_counts = re.findall(r"Total Impressions:\n.*\n.*\n...(\d*)", self._page_counter)[0]
        return total_counts


if __name__ == "__main__":
    ip = '192.168.2.145'
    print(XeroxMajor(ip).mac)



import re
import requests


class KyoceraMajor:
    def __init__(self, ip_address):
        self.ip_address = ip_address
        self.headers = {'Cookie': 'rtl=0; css=0', 'Referer': f"http://{self.ip_address}/startwlm/Start_Wlm.htm"}
        self._page_info = self._get_config_page()
        self._page_toner = self._get_toner_page()
        self._page_counter = self._page_counter()

    def _get_config_page(self):
        url_info = f'http://{self.ip_address}/js/jssrc/model/dvcinfo/dvcconfig/DvcConfig_Config.model.htm'
        page_code_info = requests.get(url_info, headers=self.headers)
        return page_code_info.text

    def _get_toner_page(self):
        url_toner = f'http://{self.ip_address}/js/jssrc/model/startwlm/Hme_Toner.model.htm'
        page_code_toner = requests.get(url_toner, headers=self.headers)
        return page_code_toner.text

    def _page_counter(self):
        url_counter = f'http://{self.ip_address}/js/jssrc/model/dvcinfo/dvccounter/DvcInfo_Counter_PrnCounter.model.htm'
        page_code_counter = requests.get(url_counter, headers=self.headers)
        return page_code_counter.text

    def mac(self):
        mac_address = re.findall(r".*macAddress = '(.*)'", self._page_info)[0]
        return mac_address

    def host_name(self):
        host_name = re.findall(r".*hostName = '(.*)'", self._page_info)[0]
        return host_name

    def model(self):
        model = re.findall(r".*model = '(.*)'", self._page_info)[0]
        return model

    def toner(self):
        toner_lvl = 'Error'
        try:
            data_toner = re.findall(r".*parseInt\('(\d*)',10\)\)", self._page_toner)  # получить остаток тонера
            toner_lvl = int(data_toner[0])
        except (ValueError, IndexError):
            pass
        finally:
            return toner_lvl

    def prints_count(self):
        printed_total = re.findall(r".*printertotal = \('(\d*)'\)", self._page_counter)[0]  # получить оттиски
        copy_total = re.findall(r".*copytotal = \('(\d*)'\)", self._page_counter)[0]        # получить сканы
        prints_count = int(printed_total) + int(copy_total)                                 # получить cумму
        return prints_count


if __name__ == "__main__":
    ip = '192.168.1.39'
    print(KyoceraMajor(ip).prints_count())



import requests
import re

url = 'http://192.168.1.88/index.html'
r1 = r'>(.*)%<'


class PantumMajor:
    def __init__(self, ip_address):
        self.ip_address = ip_address
    def get_toner(self):
        '''Парс CSS, получение списка содержищего значение заполения полоски тонера'''
        url_str = f'http://{self.ip_address}/css/style.css'
        r = requests.get(url_str).text
        value = re.findall(r".*width:.(.*)%;", r)[3]
        return value


# def get_toner(ip_address):
#         '''Парс CSS, получение списка содержищего значение заполения полоски тонера'''
#         url_str = f'http://{ip_address}/css/style.css'
#         r = requests.get(url_str).text
#         value = re.findall(r".*width:.(.*)%;", r)[3]
#         return value
#
#
# def get_info():
#     page = requests.get(url).text
#     toner = re.findall(r1, page)
#     return page
